@@ -2,7 +2,7 @@
 /*
  * GData Client
  * Copyright (C) Richard Schwarting 2009 <aquarichy@gmail.com>
- * Copyright (C) Philip Withnall 2009 <philip@tecnocode.co.uk>
+ * Copyright (C) Philip Withnall 2009–2010 <philip@tecnocode.co.uk>
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -590,6 +590,10 @@ gdata_picasaweb_file_init (GDataPicasaWebFile *self)
 	self->priv->georss_where = g_object_new (GDATA_TYPE_GEORSS_WHERE, NULL);
 	self->priv->is_commenting_enabled = TRUE;
 
+	/* Initialise the timestamp and edited properties to the current time (bgo#599140) */
+	g_get_current_time (&(self->priv->timestamp));
+	g_get_current_time (&(self->priv->edited));
+
 	/* We need to keep atom:title (the canonical title for the file) in sync with media:group/media:title */
 	g_signal_connect (self, "notify::title", G_CALLBACK (notify_title_cb), NULL);
 	/* atom:summary (the canonical summary/caption for the file) in sync with media:group/media:description */
@@ -626,7 +630,7 @@ gdata_picasaweb_file_finalize (GObject *object)
 	g_free (priv->album_id);
 	g_free (priv->client);
 	g_free (priv->checksum);
-	xmlFree (priv->video_status);
+	g_free (priv->video_status);
 
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (gdata_picasaweb_file_parent_class)->finalize (object);
@@ -833,10 +837,8 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 		xmlFree (edited);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "imageVersion") == 0) {
 		/* gphoto:imageVersion */
-		xmlChar *version = xmlNodeListGetString (doc, node->children, TRUE);
 		g_free (self->priv->version);
-		self->priv->version = g_strdup ((gchar*) version);
-		xmlFree (version);
+		self->priv->version = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "position") == 0) {
 		/* gphoto:position */
 		xmlChar *position_str = xmlNodeListGetString (doc, node->children, TRUE);
@@ -844,9 +846,7 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 		xmlFree (position_str);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "albumid") == 0) {
 		/* gphoto:album_id */
-		xmlChar *album_id = xmlNodeListGetString (doc, node->children, TRUE);
-		gdata_picasaweb_file_set_album_id (self, (gchar*) album_id);
-		xmlFree (album_id);
+		self->priv->album_id = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "width") == 0) {
 		/* gphoto:width */
 		xmlChar *width = xmlNodeListGetString (doc, node->children, TRUE);
@@ -864,14 +864,10 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 		xmlFree (size);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "client") == 0) {
 		/* gphoto:client */
-		xmlChar *client = xmlNodeListGetString (doc, node->children, TRUE);
-		gdata_picasaweb_file_set_client (self, (gchar*) client);
-		xmlFree (client);
+		self->priv->client = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "checksum") == 0) {
 		/* gphoto:checksum */
-		xmlChar *checksum = xmlNodeListGetString (doc, node->children, TRUE);
-		gdata_picasaweb_file_set_checksum (self, (gchar*) checksum);
-		xmlFree (checksum);
+		self->priv->checksum = (gchar*) xmlNodeListGetString (doc, node->children, TRUE);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "timestamp") == 0) {
 		/* gphoto:timestamp */
 		xmlChar *timestamp_str;
@@ -906,6 +902,11 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 			return gdata_parser_error_duplicate_element (node, error);
 		}
 		self->priv->video_status = (gchar*) video_status;
+	} else if (xmlStrcmp (node->name, (xmlChar*) "access") == 0) {
+		/* gphoto:access */
+		/* Visibility is already obtained through the album. When PicasaWeb supports per-file access restrictions,
+		   we'll expose this property. Until then, we'll catch this to suppress the Unhandled XML warning.
+		   See https://bugzilla.gnome.org/show_bug.cgi?id=589858 */
 	} else if (xmlStrcmp (node->name, (xmlChar*) "rotation") == 0) {
 		/* gphoto:rotation */
 		xmlChar *rotation = xmlNodeListGetString (doc, node->children, TRUE);
@@ -1509,7 +1510,11 @@ gdata_picasaweb_file_get_contents (GDataPicasaWebFile *self)
  * gdata_picasaweb_file_get_thumbnails:
  * @self: a #GDataPicasaWebFile
  *
- * Returns a list of thumbnails, often at different sizes, for this file.
+ * Returns a list of thumbnails, often at different sizes, for this
+ * file.  Currently, PicasaWeb usually returns three thumbnails, with
+ * widths in pixels of 72, 144, and 288.  However, the thumbnail will
+ * not be larger than the actual image, so thumbnails may be smaller
+ * than the widths listed above.
  *
  * Return value: a #GList of #GDataMediaThumbnail<!-- -->s, or %NULL
  *
